Reference Class to represent a bin for creating a tree of bins In which the leaf bins are the final bins that will be used
rangeA matrix which holds the start and the end values for each dimension
countThe number of the points
parentThe parent bin of the bin in the tree
isLeftSonis the son in the tree is left son
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.