Reference Class to represent an internal bin in the bins tree
left_sonthe left son of the internal bin
right_sonthe right son of the internal bin
midpointthe value that seperate the bin to left and right bins
discriminator_dimthe dimension by which the bin was separated
count_diffthe different points number between the left and the right son
pointsa matrix of the points in this bin
split(dim)split the bin into 2 sub-bins in the simension in which the count_diff is the largest
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.